@@ -11,8 +11,6 @@ def run():
     user_config = Path().cwd() / Path('config.ini')
     default_config = Path(__file__).parent / Path('config.ini')
     config = Ini(user_config) if user_config.exists() else Ini(default_config)
-    host = config['NETWORK']['host']
-    port = int(config['NETWORK']['port'])
     password = config['ADMIN']['password']
     admin = Admin(password=password)
     admin.enable_admin()
